exceptiontools.ParallelError
============================

.. inheritance-diagram:: abjad.tools.exceptiontools.ParallelError.ParallelError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ParallelError.ParallelError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ParallelError.ParallelError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
